#' @name BracarensePg43
#' @title Pessoas Condenadas Por Embriaguez
#' @description Os dados a seguir foram publicados pela Unidade de
#'     Recuperação de Acoólatras em Camberwell, Reino Unido. A tabela
#'     mostra o número de pessoas condenadas por embriaguez nos
#'     tribunais de Tower Bridge e Lambeth, Londres, durante 6 meses, de
#'     primeiro de janeiro a 27 de junho de 1970, classificados segundo
#'     idade e sexo.
#' @format Um \code{data.frame} com 5 linhas e 3 colunas, em que
#'
#' \describe{
#'
#' \item{\code{NH}}{Número de Homens.}
#'
#' \item{\code{NM}}{Número de Mulheres.}
#'
#' }
#'
#' @keywords estatística básica
#' @source BRACARENSE(2009), Exercício 2, página 43.
#' @examples
#'
#' data(BracarensePg43)
#' str(BracarensePg43)
#' levels(BracarensePg43$Idade)[c(1, 5)] <- c("<30", ">=60")
#'
#' tb <- as.matrix(BracarensePg43[, -1])
#' rownames(tb) <- BracarensePg43[, 1]
#'
#' mosaicplot(tb, main = NULL)
#'
#' barplot(tb,
#'         beside = TRUE,
#'         ylab = "Número de pessoas condenados por embriaguez")
#'
#' library(lattice)
#' library(latticeExtra)
#'
#' desloc <- function(x, groups, box.ratio, subscripts) {
#'     d <- 1/(nlevels(groups) + nlevels(groups)/box.ratio)
#'     g <- (as.numeric(groups[subscripts]) - 1)
#'     g <- (g - median(g)) * d
#'     return(as.integer(x[subscripts]) + g)
#' }
#'
#' barchart(tb,
#'          stack = FALSE,
#'          horizontal = FALSE,
#'          ylab = "Número de pessoas condenados por embriaguez") +
#'     layer(panel.text(x = desloc(x, groups, box.ratio, subscripts),
#'                      y = y,
#'                      label = y,
#'                      pos = 3))
#'
#' barchart(t(tb),
#'          stack = FALSE,
#'          horizontal = FALSE,
#'          ylab = "Número de pessoas condenados por embriaguez") +
#'     layer(panel.text(x = desloc(x, groups, box.ratio, subscripts),
#'                      y = y,
#'                      label = y,
#'                      pos = 3))
#'
NULL
